@@ -23,12 +23,6 @@ Copyright_License {
 */
 
 #include "GlideComputerBlackboard.hpp"
-#include "NMEA/Info.hpp"
-#include "NMEA/Derived.hpp"
-
-GlideComputerBlackboard::GlideComputerBlackboard()
-{
-}
 
 /**
  * Resets the GlideComputerBlackboard
@@ -83,20 +77,7 @@ GlideComputerBlackboard::RestoreFinish()
 void
 GlideComputerBlackboard::ReadBlackboard(const MoreData &nmea_info)
 {
-  _time_retreated = nmea_info.HasTimeRetreatedSince(gps_info);
-
-  if (_time_retreated) {
-    // backwards in time, so reset last
-    last_gps_info = nmea_info;
-    _time_retreated = true;
-  } else if (nmea_info.time > gps_info.time) {
-    // forwards in time, so save state
-    last_gps_info = gps_info;
-  }
-
   gps_info = nmea_info;
-
-  // if time hasn't advanced, don't copy last calculated
 }
 
 /**
