@@ -22,26 +22,31 @@ Copyright_License {
 */
 
 #include "GlueMapWindow.hpp"
-#include "Message.hpp"
 #include "Input/InputEvents.hpp"
-#include "Screen/Key.h"
 #include "Screen/Layout.hpp"
 #include "Simulator.hpp"
-#include "Task/ProtectedTaskManager.hpp"
 #include "Blackboard/DeviceBlackboard.hpp"
 #include "Components.hpp"
-#include "Protection.hpp"
 #include "Math/FastMath.h"
 #include "Compiler.h"
 #include "Interface.hpp"
 #include "Pan.hpp"
 #include "Util/Clamp.hpp"
+#include "Event/Idle.hpp"
 
 #ifdef ENABLE_SDL
 #include <SDL_keyboard.h>
 #endif
 
-#include <algorithm>
+void
+GlueMapWindow::OnDestroy()
+{
+#ifdef ENABLE_OPENGL
+  data_timer.Cancel();
+#endif
+
+  MapWindow::OnDestroy();
+}
 
 bool
 GlueMapWindow::OnMouseDouble(PixelScalar x, PixelScalar y)
@@ -378,7 +383,11 @@ GlueMapWindow::OnPaintBuffer(Canvas &canvas)
   EnterDrawThread();
 
   /* update terrain, topography, ... */
-  Idle();
+  if (Idle())
+    /* still dirty: schedule a redraw to load more data */
+    data_timer.Schedule(500);
+  else
+    data_timer.Cancel();
 #endif
 
   MapWindow::OnPaintBuffer(canvas);
@@ -418,6 +427,13 @@ GlueMapWindow::OnTimer(WindowTimer &timer)
     }
 
     return true;
+  } else if (timer == data_timer) {
+    if (!IsUserIdle(2500))
+      /* user is still active; try again later */
+      return true;
+
+    Invalidate();
+    return false;
 #endif
   } else
     return MapWindow::OnTimer(timer);
