@@ -49,6 +49,7 @@ const char DistanceUnitsValue[] = "DistanceUnit";
 const char DrawTerrain[] = "DrawTerrain";
 const char SlopeShading[] = "SlopeShading";
 const char SlopeShadingType[] = "SlopeShadingType";
+const char TerrainContours[] = "TerrainContours";
 const char DrawTopography[] = "DrawTopology";
 const char FinalGlideTerrain[] = "FinalGlideTerrain";
 const char AutoWind[] = "AutoWind";
@@ -74,6 +75,7 @@ const char DisplayTrackBearing[] = "DisplayTrackBearing";
 const char SpeedUnitsValue[] = "SpeedUnit";
 const char TaskSpeedUnitsValue[] = "TaskSpeedUnit";
 const char WarningTime[] = "WarnTime";
+const char RepetitiveSound[] = "RepetitiveSound";
 const char AcknowledgementTime[] = "AcknowledgementTime";
 const char AirfieldFile[] = "AirfieldFile"; // pL
 const char AirspaceFile[] = "AirspaceFile"; // pL
@@ -141,7 +143,6 @@ const char EnableFLARMGauge[] = "EnableFLARMGauge";
 const char AutoCloseFlarmDialog[] = "AutoCloseFlarmDialog";
 const char EnableTAGauge[] = "EnableTAGauge";
 const char EnableThermalProfile[] = "EnableThermalProfile";
-const char FLARMGaugeBearing[] = "FLARMGaugeBearing";
 const char GliderScreenPosition[] = "GliderScreenPosition";
 const char SetSystemTimeFromGPS[] = "SetSystemTimeFromGPS";
 
@@ -194,6 +195,7 @@ const char EnableFinalGlideBarMC0[] = "EnableFinalGlideBarMC0";
 const char FinalGlideBarDisplayMode[] = "FinalGlideBarDisplayMode";
 const char EnableVarioBar[] = "EnableVarioBar";
 const char ShowFAITriangleAreas[] = "ShowFAITriangleAreas";
+const char FAITriangleThreshold[] = "FAITriangleThreshold";
 const char AutoLogger[] = "AutoLogger";
 const char DisableAutoLogger[] = "DisableAutoLogger";
 const char EnableFlightLogger[] = "EnableFlightLogger";
@@ -201,10 +203,10 @@ const char EnableNMEALogger[] = "EnableNMEALogger";
 const char MapFile[] = "MapFile"; // pL
 const char BallastSecsToEmpty[] = "BallastSecsToEmpty";
 const char UseCustomFonts[] = "UseCustomFonts";
+const char DialogFont[] = "DialogFont";
 const char FontInfoWindowFont[] = "InfoWindowFont";
 const char FontTitleWindowFont[] = "TitleWindowFont";
 const char FontMapWindowFont[] = "MapWindowFont";
-const char FontTitleSmallWindowFont[] = "TeamCodeFont";
 const char FontMapWindowBoldFont[] = "MapWindowBoldFont";
 const char FontCDIWindowFont[] = "CDIWindowFont";
 const char FontMapLabelFont[] = "MapLabelFont";
