@@ -23,17 +23,15 @@ Copyright_License {
 
 #include "WaypointGlue.hpp"
 #include "Profile/Profile.hpp"
-#include "Util/StringUtil.hpp"
 #include "LogFile.hpp"
 #include "Waypoint/Waypoints.hpp"
 #include "WaypointReader.hpp"
 #include "Language/Language.hpp"
-#include "NMEA/Aircraft.hpp"
-#include "Airspace/ProtectedAirspaceWarningManager.hpp"
 #include "IO/TextWriter.hpp"
 #include "OS/PathName.hpp"
 #include "Waypoint/WaypointWriter.hpp"
 #include "Operation/Operation.hpp"
+#include "WaypointFileType.hpp"
 
 #include <windef.h> /* for MAX_PATH */
 
@@ -72,6 +70,7 @@ WaypointGlue::IsWritable(int file_number)
     return false;
 
   return (MatchesExtension(file, _T(".dat")) ||
+          MatchesExtension(file, _T(".cup")) ||
           MatchesExtension(file, _T(".xcw")));
 }
 
@@ -166,7 +165,7 @@ WaypointGlue::SaveWaypointFile(const Waypoints &way_points, int num)
   }
 
   WaypointWriter wp_writer(way_points, num);
-  wp_writer.Save(writer);
+  wp_writer.Save(writer, DetermineWaypointFileType(file));
 
   LogFormat("Waypoint file %d saved", num);
   return true;
