@@ -38,21 +38,9 @@ XMLWidget::LoadWindow(const CallBackTableEntry *callbacks,
   SetWindow(window);
 }
 
-void
-XMLWidget::LoadWindow(const CallBackTableEntry *callbacks,
-                      ContainerWindow &parent, const TCHAR *resource)
-{
-  WindowStyle style;
-  style.Hide();
-
-  Window *window = ::LoadWindow(callbacks, &form, parent, resource, style);
-  assert(window != NULL);
-  SetWindow(window);
-}
-
 bool
 XMLWidget::SetFocus()
 {
-  ContainerWindow &window = *(ContainerWindow *)GetWindow();
+  ContainerWindow &window = (ContainerWindow &)GetWindow();
   return window.FocusFirstControl();
 }
